from setuptools import setup

setup(
    name='automation-utilities',
    version='1.0.1',
    author='Hazem Oukal',
    description='Some utilities that I use for automation works',
    packages=['automation_utilities'],
    install_requires=[],
)
